@@ -3,7 +3,7 @@
  *
  * Copyright(c) 2000-2001 by Reed Lai
  * Copyright(c) 2001 by Timecop <timecop@japan.co.jp>
- * Copyright(c) 2001-2008 by wave++ "Yuri D'Elia" <wavexx@users.sf.net>
+ * Copyright(c) 2001-2020 by wave++ "Yuri D'Elia" <wavexx@thregr.org>
  *
  * Distributed under GNU GPL (v2 or above) WITHOUT ANY WARRANTY.
  */
@@ -1462,24 +1462,28 @@ draw_stats(struct Devices *ptr, const int gap)
     tx_max_his = ptr->op_max_his;
   }
 
-  /* find maximum value in screen history */
-  rx_max = tx_max = 0;
-  p = (unsigned long*)ptr->his;
-  for(k = 0; k < 58; k++)
+  /* find maximum value */
+  if(!bit_get(CFG_MAXSCREEN))
   {
-    rx_max = MAX(rx_max, p[in]);
-    tx_max = MAX(tx_max, p[out]);
-    p += 4;
+    rx_max = rx_max_his;
+    tx_max = tx_max_his;
+  }
+  else
+  {
+    rx_max = tx_max = 0;
+    p = (unsigned long*)ptr->his;
+    for(k = 0; k < 58; k++)
+    {
+      rx_max = MAX(rx_max, p[in]);
+      tx_max = MAX(tx_max, p[out]);
+      p += 4;
+    }
   }
 
   /* draw rx/tx rate */
   p = ptr->avg;
   draw_rate(p[in], p[out], gap);
-
-  if(bit_get(CFG_MAXSCREEN))
-    draw_max(rx_max, tx_max);
-  else
-    draw_max(rx_max_his, tx_max_his);
+  draw_max(rx_max, tx_max);
 
   p = (unsigned long*)ptr->his;
   (*drwFuncs[wmnd.wavemode].funcPtr)(p, in, out, size, rx_max, tx_max);
